@@ -26,6 +26,9 @@ class H2OAutoMLRegressor(H2OAutoML):
 
     @keyword_only
     def __init__(self,
+                 ignoredCols=None,
+                 leaderboardDataFrame=None,
+                 blendingDataFrame=None,
                  columnsToCategorical=[],
                  withContributions=False,
                  withLeafNodeAssignments=False,
@@ -37,7 +40,6 @@ class H2OAutoMLRegressor(H2OAutoML):
                  predictionCol="prediction",
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
-                 ignoredCols=None,
                  monotoneConstraints={},
                  withStageResults=False,
                  withDetailedPredictionCol=True,
