@@ -258,6 +258,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """In case of linearly dependent columns, remove some of the dependent columns""",
         H2OTypeConverters.toBoolean())
 
+    generateScoringHistory = Param(
+        Params._dummy(),
+        "generateScoringHistory",
+        """If set to true, will generate scoring history for GLM.  This may significantly slow down the algo.""",
+        H2OTypeConverters.toBoolean())
+
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -297,7 +303,7 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -495,6 +501,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getRemoveCollinearCols(self):
         return self.getOrDefault(self.removeCollinearCols)
 
+    def getGenerateScoringHistory(self):
+        return self.getOrDefault(self.generateScoringHistory)
+
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -672,6 +681,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setRemoveCollinearCols(self, value):
         return self._set(removeCollinearCols=value)
 
+    def setGenerateScoringHistory(self, value):
+        return self._set(generateScoringHistory=value)
+
     def setModelId(self, value):
         return self._set(modelId=value)
 
